Welcome to ASTROMER documentation!
**********************************************************

**ASTROMER** is a transformer based model pretrained on millions of light curves. ASTROMER can be finetuned on specific datasets to create useful representations that can improve the performance of novel deep learning models.

❗ This version of ASTROMER can only works on single band light curves.

This project `was published <https://arxiv.org/abs/2205.01677/>`_ by C. Donoso-Oliva, I. Becker, P. Protopapas, G. Cabrera-Vives, M. Vishnu and H. Vardhan, 2023, A&A, 670, A54.

.. important::

    This sample documentation was generated on |today|, and is rebuilt weekly.

.. toctree::
   :maxdepth: 4
   :caption: LIBRARY DOCUMENTATION

   ASTROMER


Resources
-----------------------------------------------

- `ASTROMER Documentation <https://astromer.readthedocs.io/en/latest/>`_
- `ASTROMER Tutorials <https://www.stellardnn.org/astromer/>`_

Contributing to ASTROMER
---------------------------------------------

.. epigraph:: If you train your model from scratch, you can share your pre-trained weights by submitting a Pull Request on `the weights repository <https://github.com/astromer-science/weights>`_
